@@ -13,6 +13,7 @@
 from dataclasses import dataclass
 import typing_extensions
 import urllib3
+from snaptrade_client.request_before_hook import request_before_hook
 import json
 from urllib3._collections import HTTPHeaderDict
 
@@ -31,9 +32,15 @@ import frozendict  # noqa: F401
 
 from snaptrade_client import schemas  # noqa: F401
 
+from snaptrade_client.model.cash_restriction import CashRestriction as CashRestrictionSchema
 from snaptrade_client.model.account import Account as AccountSchema
+from snaptrade_client.model.account_sync_status import AccountSyncStatus as AccountSyncStatusSchema
+from snaptrade_client.model.account_meta import AccountMeta as AccountMetaSchema
 
 from snaptrade_client.type.account import Account
+from snaptrade_client.type.cash_restriction import CashRestriction
+from snaptrade_client.type.account_meta import AccountMeta
+from snaptrade_client.type.account_sync_status import AccountSyncStatus
 
 from . import path
 
@@ -114,8 +121,8 @@ class SchemaFor200ResponseBodyApplicationJson(
     class MetaOapg:
         
         @staticmethod
-        def items() -> typing.Type['Account']:
-            return Account
+        def items() -> typing.Type['AccountSchema']:
+            return AccountSchema
 
     def __new__(
         cls,
@@ -253,17 +260,33 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'put'.upper()
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            auth_settings=_auth,
+            headers=_headers,
+        )
     
         response = await self.api_client.async_call_api(
             resource_path=used_path,
-            method='put'.upper(),
+            method=method,
             headers=_headers,
             auth_settings=_auth,
             prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
         )
-        
+    
         if stream:
+            if not 200 <= response.http_response.status <= 299:
+                body = (await response.http_response.content.read()).decode("utf-8")
+                raise exceptions.ApiStreamingException(
+                    status=response.http_response.status,
+                    reason=response.http_response.reason,
+                    body=body,
+                )
+    
             async def stream_iterator():
                 """
                 iterates over response.http_response.content and closes connection once iteration has finished
@@ -313,6 +336,7 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
     def _update_user_account_oapg(
         self,
         query_params: typing.Optional[dict] = {},
@@ -368,10 +392,18 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'put'.upper()
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            auth_settings=_auth,
+            headers=_headers,
+        )
     
         response = self.api_client.call_api(
             resource_path=used_path,
-            method='put'.upper(),
+            method=method,
             headers=_headers,
             auth_settings=_auth,
             prefix_separator_iterator=prefix_separator_iterator,
@@ -406,6 +438,7 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
 class UpdateUserAccount(BaseApi):
     # this class is used by api classes that refer to endpoints with operationId fn names
 
