@@ -32,13 +32,61 @@ import frozendict  # noqa: F401
 
 from snaptrade_client import schemas  # noqa: F401
 
+from snaptrade_client.model.cash_restriction import CashRestriction as CashRestrictionSchema
 from snaptrade_client.model.model400_failed_request_response import Model400FailedRequestResponse as Model400FailedRequestResponseSchema
+from snaptrade_client.model.stop_price import StopPrice as StopPriceSchema
+from snaptrade_client.model.snap_trade_holdings_account_account_id_meta import SnapTradeHoldingsAccountAccountIdMeta as SnapTradeHoldingsAccountAccountIdMetaSchema
+from snaptrade_client.model.position_symbol import PositionSymbol as PositionSymbolSchema
+from snaptrade_client.model.position import Position as PositionSchema
+from snaptrade_client.model.options_symbol import OptionsSymbol as OptionsSymbolSchema
+from snaptrade_client.model.cancelled_units import CancelledUnits as CancelledUnitsSchema
+from snaptrade_client.model.filled_units import FilledUnits as FilledUnitsSchema
+from snaptrade_client.model.snap_trade_holdings_account_account_id import SnapTradeHoldingsAccountAccountId as SnapTradeHoldingsAccountAccountIdSchema
+from snaptrade_client.model.currency import Currency as CurrencySchema
+from snaptrade_client.model.underlying_symbol import UnderlyingSymbol as UnderlyingSymbolSchema
+from snaptrade_client.model.exchange import Exchange as ExchangeSchema
+from snaptrade_client.model.balance import Balance as BalanceSchema
+from snaptrade_client.model.time_in_force import TimeInForce as TimeInForceSchema
+from snaptrade_client.model.security_type import SecurityType as SecurityTypeSchema
+from snaptrade_client.model.order_type import OrderType as OrderTypeSchema
 from snaptrade_client.model.model403_failed_request_response import Model403FailedRequestResponse as Model403FailedRequestResponseSchema
+from snaptrade_client.model.price import Price as PriceSchema
+from snaptrade_client.model.action import Action as ActionSchema
+from snaptrade_client.model.snap_trade_holdings_total_value import SnapTradeHoldingsTotalValue as SnapTradeHoldingsTotalValueSchema
+from snaptrade_client.model.account_order_record import AccountOrderRecord as AccountOrderRecordSchema
+from snaptrade_client.model.us_exchange import USExchange as USExchangeSchema
 from snaptrade_client.model.account_holdings_account import AccountHoldingsAccount as AccountHoldingsAccountSchema
+from snaptrade_client.model.universal_symbol import UniversalSymbol as UniversalSymbolSchema
+from snaptrade_client.model.open_units import OpenUnits as OpenUnitsSchema
+from snaptrade_client.model.account_order_record_status import AccountOrderRecordStatus as AccountOrderRecordStatusSchema
 
-from snaptrade_client.type.account_holdings_account import AccountHoldingsAccount
-from snaptrade_client.type.model400_failed_request_response import Model400FailedRequestResponse
+from snaptrade_client.type.account_order_record_status import AccountOrderRecordStatus
+from snaptrade_client.type.balance import Balance
+from snaptrade_client.type.security_type import SecurityType
+from snaptrade_client.type.snap_trade_holdings_total_value import SnapTradeHoldingsTotalValue
+from snaptrade_client.type.stop_price import StopPrice
 from snaptrade_client.type.model403_failed_request_response import Model403FailedRequestResponse
+from snaptrade_client.type.price import Price
+from snaptrade_client.type.options_symbol import OptionsSymbol
+from snaptrade_client.type.position import Position
+from snaptrade_client.type.account_holdings_account import AccountHoldingsAccount
+from snaptrade_client.type.exchange import Exchange
+from snaptrade_client.type.snap_trade_holdings_account_account_id import SnapTradeHoldingsAccountAccountId
+from snaptrade_client.type.us_exchange import USExchange
+from snaptrade_client.type.underlying_symbol import UnderlyingSymbol
+from snaptrade_client.type.open_units import OpenUnits
+from snaptrade_client.type.universal_symbol import UniversalSymbol
+from snaptrade_client.type.time_in_force import TimeInForce
+from snaptrade_client.type.filled_units import FilledUnits
+from snaptrade_client.type.model400_failed_request_response import Model400FailedRequestResponse
+from snaptrade_client.type.currency import Currency
+from snaptrade_client.type.order_type import OrderType
+from snaptrade_client.type.action import Action
+from snaptrade_client.type.cancelled_units import CancelledUnits
+from snaptrade_client.type.cash_restriction import CashRestriction
+from snaptrade_client.type.position_symbol import PositionSymbol
+from snaptrade_client.type.account_order_record import AccountOrderRecord
+from snaptrade_client.type.snap_trade_holdings_account_account_id_meta import SnapTradeHoldingsAccountAccountIdMeta
 
 from . import path
 
@@ -236,7 +284,7 @@ class BaseApi(api_client.Api):
         AsyncGeneratorResponse,
     ]:
         """
-        List balances, positions and orders for the specified account.
+        List balances, positions and orders for the specified account
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -362,7 +410,7 @@ class BaseApi(api_client.Api):
         api_client.ApiResponseWithoutDeserialization,
     ]:
         """
-        List balances, positions and orders for the specified account.
+        List balances, positions and orders for the specified account
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
