@@ -13,6 +13,7 @@
 from dataclasses import dataclass
 import typing_extensions
 import urllib3
+from snaptrade_client.request_before_hook import request_before_hook
 import json
 from urllib3._collections import HTTPHeaderDict
 
@@ -31,9 +32,31 @@ import frozendict  # noqa: F401
 
 from snaptrade_client import schemas  # noqa: F401
 
+from snaptrade_client.model.exchange import Exchange as ExchangeSchema
+from snaptrade_client.model.net_dividend import NetDividend as NetDividendSchema
+from snaptrade_client.model.sub_period_return_rate import SubPeriodReturnRate as SubPeriodReturnRateSchema
+from snaptrade_client.model.monthly_dividends import MonthlyDividends as MonthlyDividendsSchema
 from snaptrade_client.model.performance_custom import PerformanceCustom as PerformanceCustomSchema
+from snaptrade_client.model.security_type import SecurityType as SecurityTypeSchema
+from snaptrade_client.model.performance_custom_bad_tickers import PerformanceCustomBadTickers as PerformanceCustomBadTickersSchema
+from snaptrade_client.model.net_contributions import NetContributions as NetContributionsSchema
+from snaptrade_client.model.past_value import PastValue as PastValueSchema
+from snaptrade_client.model.currency import Currency as CurrencySchema
+from snaptrade_client.model.dividend_at_date import DividendAtDate as DividendAtDateSchema
+from snaptrade_client.model.universal_symbol import UniversalSymbol as UniversalSymbolSchema
 
 from snaptrade_client.type.performance_custom import PerformanceCustom
+from snaptrade_client.type.past_value import PastValue
+from snaptrade_client.type.dividend_at_date import DividendAtDate
+from snaptrade_client.type.monthly_dividends import MonthlyDividends
+from snaptrade_client.type.security_type import SecurityType
+from snaptrade_client.type.exchange import Exchange
+from snaptrade_client.type.currency import Currency
+from snaptrade_client.type.sub_period_return_rate import SubPeriodReturnRate
+from snaptrade_client.type.performance_custom_bad_tickers import PerformanceCustomBadTickers
+from snaptrade_client.type.universal_symbol import UniversalSymbol
+from snaptrade_client.type.net_contributions import NetContributions
+from snaptrade_client.type.net_dividend import NetDividend
 
 from . import path
 
@@ -243,17 +266,33 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'get'.upper()
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            auth_settings=_auth,
+            headers=_headers,
+        )
     
         response = await self.api_client.async_call_api(
             resource_path=used_path,
-            method='get'.upper(),
+            method=method,
             headers=_headers,
             auth_settings=_auth,
             prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
         )
-        
+    
         if stream:
+            if not 200 <= response.http_response.status <= 299:
+                body = (await response.http_response.content.read()).decode("utf-8")
+                raise exceptions.ApiStreamingException(
+                    status=response.http_response.status,
+                    reason=response.http_response.reason,
+                    body=body,
+                )
+    
             async def stream_iterator():
                 """
                 iterates over response.http_response.content and closes connection once iteration has finished
@@ -303,6 +342,7 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
     def _get_reporting_custom_range_oapg(
         self,
         query_params: typing.Optional[dict] = {},
@@ -348,10 +388,18 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'get'.upper()
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            auth_settings=_auth,
+            headers=_headers,
+        )
     
         response = self.api_client.call_api(
             resource_path=used_path,
-            method='get'.upper(),
+            method=method,
             headers=_headers,
             auth_settings=_auth,
             prefix_separator_iterator=prefix_separator_iterator,
@@ -386,6 +434,7 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
 class GetReportingCustomRange(BaseApi):
     # this class is used by api classes that refer to endpoints with operationId fn names
 
