@@ -13,6 +13,7 @@
 from dataclasses import dataclass
 import typing_extensions
 import urllib3
+from snaptrade_client.request_before_hook import request_before_hook
 import json
 from urllib3._collections import HTTPHeaderDict
 
@@ -34,11 +35,13 @@ from snaptrade_client import schemas  # noqa: F401
 from snaptrade_client.model.model400_failed_request_response import Model400FailedRequestResponse as Model400FailedRequestResponseSchema
 from snaptrade_client.model.snap_trade_register_user_request_body import SnapTradeRegisterUserRequestBody as SnapTradeRegisterUserRequestBodySchema
 from snaptrade_client.model.user_i_dand_secret import UserIDandSecret as UserIDandSecretSchema
+from snaptrade_client.model.model500_unexpected_exception_response import Model500UnexpectedExceptionResponse as Model500UnexpectedExceptionResponseSchema
 from snaptrade_client.model.model404_failed_request_response import Model404FailedRequestResponse as Model404FailedRequestResponseSchema
 
 from snaptrade_client.type.snap_trade_register_user_request_body import SnapTradeRegisterUserRequestBody
 from snaptrade_client.type.model400_failed_request_response import Model400FailedRequestResponse
 from snaptrade_client.type.user_i_dand_secret import UserIDandSecret
+from snaptrade_client.type.model500_unexpected_exception_response import Model500UnexpectedExceptionResponse
 from snaptrade_client.type.model404_failed_request_response import Model404FailedRequestResponse
 
 from . import path
@@ -122,21 +125,26 @@ _response_for_404 = api_client.OpenApiResponse(
             schema=SchemaFor404ResponseBodyApplicationJson),
     },
 )
+SchemaFor500ResponseBodyApplicationJson = Model500UnexpectedExceptionResponseSchema
 
 
 @dataclass
 class ApiResponseFor500(api_client.ApiResponse):
-    body: schemas.Unset = schemas.unset
+    body: Model500UnexpectedExceptionResponse
 
 
 @dataclass
 class ApiResponseFor500Async(api_client.AsyncApiResponse):
-    body: schemas.Unset = schemas.unset
+    body: Model500UnexpectedExceptionResponse
 
 
 _response_for_500 = api_client.OpenApiResponse(
     response_cls=ApiResponseFor500,
     response_cls_async=ApiResponseFor500Async,
+    content={
+        'application/json': api_client.MediaType(
+            schema=SchemaFor500ResponseBodyApplicationJson),
+    },
 )
 _status_code_to_response = {
     '200': _response_for_200,
@@ -155,14 +163,11 @@ class BaseApi(api_client.Api):
         self,
         body: typing.Optional[SnapTradeRegisterUserRequestBody] = None,
         user_id: typing.Optional[str] = None,
-        rsa_public_key: typing.Optional[str] = None,
     ) -> api_client.MappedArgs:
         args: api_client.MappedArgs = api_client.MappedArgs()
         _body = {}
         if user_id is not None:
             _body["userId"] = user_id
-        if rsa_public_key is not None:
-            _body["rsaPublicKey"] = rsa_public_key
         args.body = body if body is not None else _body
         return args
 
@@ -180,7 +185,7 @@ class BaseApi(api_client.Api):
         AsyncGeneratorResponse,
     ]:
         """
-        Register user with SnapTrade in order to create secure brokerage authorizations
+        Create SnapTrade user
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -192,21 +197,31 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'post'.upper()
+        _headers.add('Content-Type', content_type)
     
         if body is schemas.unset:
             raise exceptions.ApiValueError(
                 'The required body parameter has an invalid value of: unset. Set a valid value instead')
         _fields = None
         _body = None
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            body=body,
+            auth_settings=_auth,
+            headers=_headers,
+        )
         serialized_data = request_body_snap_trade_register_user_request_body.serialize(body, content_type)
-        _headers.add('Content-Type', content_type)
         if 'fields' in serialized_data:
             _fields = serialized_data['fields']
         elif 'body' in serialized_data:
-            _body = serialized_data['body']    
+            _body = serialized_data['body']
+    
         response = await self.api_client.async_call_api(
             resource_path=used_path,
-            method='post'.upper(),
+            method=method,
             headers=_headers,
             fields=_fields,
             serialized_body=_body,
@@ -214,8 +229,16 @@ class BaseApi(api_client.Api):
             auth_settings=_auth,
             timeout=timeout,
         )
-        
+    
         if stream:
+            if not 200 <= response.http_response.status <= 299:
+                body = (await response.http_response.content.read()).decode("utf-8")
+                raise exceptions.ApiStreamingException(
+                    status=response.http_response.status,
+                    reason=response.http_response.reason,
+                    body=body,
+                )
+    
             async def stream_iterator():
                 """
                 iterates over response.http_response.content and closes connection once iteration has finished
@@ -260,6 +283,7 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
     def _register_snap_trade_user_oapg(
         self,
         body: typing.Any = None,
@@ -273,7 +297,7 @@ class BaseApi(api_client.Api):
         api_client.ApiResponseWithoutDeserialization,
     ]:
         """
-        Register user with SnapTrade in order to create secure brokerage authorizations
+        Create SnapTrade user
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -285,21 +309,31 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'post'.upper()
+        _headers.add('Content-Type', content_type)
     
         if body is schemas.unset:
             raise exceptions.ApiValueError(
                 'The required body parameter has an invalid value of: unset. Set a valid value instead')
         _fields = None
         _body = None
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            body=body,
+            auth_settings=_auth,
+            headers=_headers,
+        )
         serialized_data = request_body_snap_trade_register_user_request_body.serialize(body, content_type)
-        _headers.add('Content-Type', content_type)
         if 'fields' in serialized_data:
             _fields = serialized_data['fields']
         elif 'body' in serialized_data:
-            _body = serialized_data['body']    
+            _body = serialized_data['body']
+    
         response = self.api_client.call_api(
             resource_path=used_path,
-            method='post'.upper(),
+            method=method,
             headers=_headers,
             fields=_fields,
             serialized_body=_body,
@@ -331,6 +365,7 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
 class RegisterSnapTradeUser(BaseApi):
     # this class is used by api classes that refer to endpoints with operationId fn names
 
@@ -338,7 +373,6 @@ class RegisterSnapTradeUser(BaseApi):
         self,
         body: typing.Optional[SnapTradeRegisterUserRequestBody] = None,
         user_id: typing.Optional[str] = None,
-        rsa_public_key: typing.Optional[str] = None,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -347,7 +381,6 @@ class RegisterSnapTradeUser(BaseApi):
         args = self._register_snap_trade_user_mapped_args(
             body=body,
             user_id=user_id,
-            rsa_public_key=rsa_public_key,
         )
         return await self._aregister_snap_trade_user_oapg(
             body=args.body,
@@ -357,7 +390,6 @@ class RegisterSnapTradeUser(BaseApi):
         self,
         body: typing.Optional[SnapTradeRegisterUserRequestBody] = None,
         user_id: typing.Optional[str] = None,
-        rsa_public_key: typing.Optional[str] = None,
     ) -> typing.Union[
         ApiResponseFor200,
         api_client.ApiResponseWithoutDeserialization,
@@ -365,7 +397,6 @@ class RegisterSnapTradeUser(BaseApi):
         args = self._register_snap_trade_user_mapped_args(
             body=body,
             user_id=user_id,
-            rsa_public_key=rsa_public_key,
         )
         return self._register_snap_trade_user_oapg(
             body=args.body,
@@ -378,7 +409,6 @@ class ApiForpost(BaseApi):
         self,
         body: typing.Optional[SnapTradeRegisterUserRequestBody] = None,
         user_id: typing.Optional[str] = None,
-        rsa_public_key: typing.Optional[str] = None,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -387,7 +417,6 @@ class ApiForpost(BaseApi):
         args = self._register_snap_trade_user_mapped_args(
             body=body,
             user_id=user_id,
-            rsa_public_key=rsa_public_key,
         )
         return await self._aregister_snap_trade_user_oapg(
             body=args.body,
@@ -397,7 +426,6 @@ class ApiForpost(BaseApi):
         self,
         body: typing.Optional[SnapTradeRegisterUserRequestBody] = None,
         user_id: typing.Optional[str] = None,
-        rsa_public_key: typing.Optional[str] = None,
     ) -> typing.Union[
         ApiResponseFor200,
         api_client.ApiResponseWithoutDeserialization,
@@ -405,7 +433,6 @@ class ApiForpost(BaseApi):
         args = self._register_snap_trade_user_mapped_args(
             body=body,
             user_id=user_id,
-            rsa_public_key=rsa_public_key,
         )
         return self._register_snap_trade_user_oapg(
             body=args.body,
