@@ -17,6 +17,8 @@ from typing_extensions import TypedDict, Literal
 
 from snaptrade_client.type.brokerage import Brokerage
 from snaptrade_client.type.brokerage_authorization_meta import BrokerageAuthorizationMeta
+from snaptrade_client.type.brokerage_exchanges import BrokerageExchanges
+from snaptrade_client.type.brokerage_type import BrokerageType
 
 class RequiredBrokerageAuthorization(TypedDict):
     pass
