@@ -15,6 +15,10 @@ import typing
 from enum import Enum
 from typing_extensions import TypedDict, Literal
 
+from snaptrade_client.type.currency import Currency
+from snaptrade_client.type.exchange import Exchange
+from snaptrade_client.type.option_strategy_legs import OptionStrategyLegs
+from snaptrade_client.type.security_type import SecurityType
 from snaptrade_client.type.universal_symbol import UniversalSymbol
 
 class RequiredOptionStrategy(TypedDict):
@@ -29,7 +33,7 @@ class OptionalOptionStrategy(TypedDict, total=False):
 
     number_of_legs: typing.Union[int, float]
 
-    legs: typing.List[typing.Union[bool, date, datetime, dict, float, int, list, str, None]]
+    legs: OptionStrategyLegs
 
 class OptionStrategy(RequiredOptionStrategy, OptionalOptionStrategy):
     pass
